@@ -50,7 +50,7 @@ class Docker(object):
     sys.stdout.write('\r' + prefix + ' [')
     line_len += len(prefix) + 2
     if nb_traits < 50:
-      for i in range(1, 50, 1):
+      for i in range(1, 51, 1):
         if i == nb_traits:
           sys.stdout.write('>')
         elif i < nb_traits:
@@ -71,8 +71,6 @@ class Docker(object):
 
   @staticmethod
   def __get_auth_head(repository):
-    Docker.__print('{}: Authenticating...'.format(repository))
-
     uri = 'https://auth.docker.io/token?service=registry.docker.io&scope=repository:{}:pull'.format(repository)
     
     request = Request(method='GET', url=uri)
@@ -109,9 +107,10 @@ class Docker(object):
     tag = repository + ':sha256(' + layer['digest'][7:19] + ')'
     file = source.strip(os.path.sep)
 
-    Docker.__print('{}: Downloading...'.format(tag))
-
-    uri = 'https://index.docker.io/v2/{}/blobs/{}'.format(repository, layer['digest'])
+    if len(layer.get('urls', [])):
+      uri = layer['urls'][0]
+    else:
+      uri = 'https://index.docker.io/v2/{}/blobs/{}'.format(repository, layer['digest'])
     
     auth_headers = Docker.__get_auth_head(repository)
     request = Request(method='GET', url=uri)
@@ -121,12 +120,14 @@ class Docker(object):
 
     assert response.status == 200, 'unable to download layer {}:{} with {} {}'.format(repository, layer['digest'], response.status, response.read().decode('utf-8'))
 
+    Docker.__progress_bar('{}: Downloading'.format(tag), 0, 50)
+
     total_size = int(response.getheader('Content-Length'))
     block_size = max(int(total_size/1000), 1024**2)
     downloaded_size = 0
 
     fileobj = io.BytesIO()
-    Docker.__progress_bar('{}: Downloading'.format(tag), 0, total_size)
+
     while downloaded_size < total_size:
       block = response.read(min(block_size, total_size-downloaded_size))
       if not block:
@@ -144,20 +145,18 @@ class Docker(object):
       Docker.__print('')
       return False
 
-    Docker.__print('{}: Scanning for /{}'.format(tag, file))
+    Docker.__progress_bar('{}: Scanning'.format(tag), 0, 50)
 
     with tarfile.open(fileobj=fileobj, bufsize=total_size, mode='r:gz') as tarf:
       members = tarf.getmembers()
       total_members = len(members)
 
-      Docker.__progress_bar('{}: Scanning for /{}'.format(tag, file), 0, total_members)
-
       for idx, member in enumerate(members):
-        Docker.__progress_bar('{}: Scanning for /{}'.format(tag, file), idx+1, total_members)
+        Docker.__progress_bar('{}: Scanning'.format(tag), idx+1, total_members)
         if member.name != file:
           continue
         tgt = os.path.realpath(os.path.join(target, os.path.basename(file)))
-        Docker.__print('{}: Extracting /{} into {}...'.format(tag, file, tgt))
+        Docker.__print('{}: Extracting...'.format(tag))
         
         with tarf.extractfile(member) as fs:
           with open(tgt, 'wb') as fd:
